Installation
------------

With ``pip``
~~~~~~~~~~~~

Requires Python 3.12+.

.. code-block:: shell

   pip install doccmd

With Homebrew (macOS, Linux, WSL)
~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~

Requires `Homebrew`_.

.. code-block:: shell

   brew tap adamtheturtle/doccmd
   brew install doccmd

.. _Homebrew: https://docs.brew.sh/Installation

Pre-built Linux binaries
~~~~~~~~~~~~~~~~~~~~~~~~

.. code-block:: console
   :substitutions:

   $ curl --fail -L https://github.com/|github-owner|/|github-repository|/releases/download/|release|/doccmd -o /usr/local/bin/doccmd && \
   $ chmod +x /usr/local/bin/doccmd
